pyscipopt: Python interface and modeling environment for SCIP
=============================================================

Description
-----------

Python interface and modeling environment for SCIP

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/PySCIPOpt/

